#!/usr/bin/env python
import logging
import os
from argparse import ArgumentParser
from concurrent.futures import ThreadPoolExecutor, as_completed
from .lib.app import AppService
from .lib.utils import chkpath, mklog


def get_args():
    parser = ArgumentParser(
        description="Start or stop Azure App Services and their slots"
    )
    parser.add_argument(
        "-a",
        "--app_services",
        nargs="+",
        metavar=("NAME"),
        help="list of azure app services",
    )
    parser.add_argument(
        "-r", "--resource_group", metavar=("NAME"), help="azure resource group"
    )
    parser.add_argument(
        "-A",
        "--action",
        metavar=("START/STOP"),
        help="action to carry out - enable or disable.",
    )
    parser.add_argument(
        "-C",
        "--config",
        type=chkpath,
        metavar=("PATH"),
        default=f"{os.path.expanduser('~')}/.azure.ini",
        help="path to azure configuration file",
    )
    parser.add_argument("-v", action="count", default=0, help="increase verbosity")
    return parser.parse_args()


def asctl(config, rg, apps, action):
    app_service = AppService(config, rg)

    # http://masnun.com/2016/03/29/python-a-quick-introduction-to-the-concurrent-futures-module.html
    with ThreadPoolExecutor(max_workers=len(apps)) as executor:
        future_app = {
            executor.submit(app_service.toggle_app_service, app, action): app
            for app in apps
        }
        for future in as_completed(future_app):
            app = future_app[future]
            print(f"Sending {action} to {app}.. ", end="", flush="True")
            try:
                result = future.result()
            except ValueError as error:
                print(f"FAILED.")
                logging.error(error)
            else:
                print(result.upper() + ".")

    for app in apps:
        slots = [
            slot["name"].split("/")[1]
            for slot in app_service.list_app_service_slots(app)["value"]
        ]
        logging.info("Found " + ", ".join(slots) + " slots for " + app)
        with ThreadPoolExecutor(max_workers=len(slots)) as executor:
            future_slot = {
                executor.submit(
                    app_service.toggle_app_service_slot, app, slot, action
                ): slot
                for slot in slots
            }
            for future in as_completed(future_slot):
                slot = future_slot[future]
                print(f"Sending {action} to {slot}.. ", end="", flush="True")
                try:
                    result = future.result()
                except ValueError as error:
                    print(f"FAILED.")
                    logging.error(error)
                else:
                    print(result.upper() + ".")


def main():
    args = get_args()
    mklog(args.v)
    asctl(args.config, args.resource_group, args.app_services, args.action)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
import json
import logging
import os
from argparse import ArgumentParser
from .lib.kudu import KuduClient
from .lib.utils import chkpath, mklog


def get_args():
    parser = ArgumentParser(description="CLI Kudu API Frontend")
    parser.add_argument("-a", "--app", metavar=("NAME"), help="azure app service name")
    parser.add_argument(
        "-C",
        "--config",
        type=chkpath,
        metavar=("PATH"),
        default=f"{os.path.expanduser('~')}/.azure.ini",
        help="path to azure configuration file",
    )
    parser.add_argument("-r", "--rg", metavar=("NAME"), help="azure resource group")
    group = parser.add_mutually_exclusive_group(required=True)
    group.add_argument(
        "-c",
        "--cmd",
        metavar=("COMMAND"),
        help="command to run (use quotes for multi-word commands)",
    )
    group.add_argument("-e", "--endpoint", metavar=("SLUG"), help="api endpoint slug")
    group.add_argument(
        "-z",
        "--deploy_zip",
        metavar=("PATH"),
        type=chkpath,
        help="upload a zip to the server",
    )
    group.add_argument(
        "-Z",
        "--download_zip",
        default=["site/wwwroot", f"{os.path.expanduser('~')}/backup.zip"],
        nargs=2,
        metavar=("SOURCE", "DESTINATION"),
        help="download a zip of a remote path",
    )
    parser.add_argument(
        "-p",
        "--cwd",
        default="site/wwwroot",
        metavar=("PATH"),
        help="server current working directory",
    )
    parser.add_argument("-v", action="count", default=0, help="increase verbosity")
    return parser.parse_args()


def run_cmd(kudu, cmd, cwd):
    print(f"Running {cmd} in {kudu.app}/{cwd}.. ", end="", flush="True")
    try:
        response = kudu.run_cmd(cmd, cwd)
        if response["Error"] == "":
            print("DONE.")
        else:
            print("FAILED.")
            raise AssertionError(
                +f"Exitcode: {response['ExitCode']} "
                + f"Message: {response['Error']}".strip()
            )
        print(response["Output"].strip())
    except Exception as error:
        logging.error(error)


def get_endpoint(kudu, endpoint):
    print(f"Getting resource from {kudu.app}/{endpoint}.. ", end="", flush="True")
    try:
        response = kudu.get_endpoint(endpoint)
        print("Done.")
        if response:
            logging.info(f"{kudu.app}{endpoint}:")
            print(json.dumps(response, indent=2, sort_keys=True))
        else:
            logging.info(f"{kudu.app}{endpoint} returned no data.")
    except Exception as error:
        print("FAILED.")
        logging.error(error)


def deploy_zip(kudu, path):
    print(f"Deploying {path} to {kudu.app}.. ", end="", flush="True")
    try:
        response = kudu.deploy_zip(path)
        print(f"DONE.") if response["complete"] else print(f"FAILED.")
        logging.info("\n" + json.dumps(response, indent=2, sort_keys=True))
    except Exception as error:
        print(f"FAILED.")
        logging.error(error)


def download_zip(kudu, paths):
    source, destination = paths
    print(
        f"Downloading zip from {kudu.app}/{source} to {destination}.. ",
        end="",
        flush="True",
    )
    try:
        response = kudu.download_zip(source, destination)
        print("DONE.") if response.ok else print("FAILED.")
    except Exception as error:
        print(f"FAILED.")
        logging.error(error)


def main():
    args = get_args()
    mklog(args.v)

    kudu = KuduClient(args.config, args.rg, args.app)

    if args.cmd:
        run_cmd(kudu, args.cmd, args.cwd)
    elif args.endpoint:
        get_endpoint(kudu, args.endpoint)
    elif args.deploy_zip:
        deploy_zip(kudu, args.deploy_zip)
    elif args.download_zip:
        download_zip(kudu, args.download_zip)


if __name__ == "__main__":
    main()



import os
import logging

from argparse import ArgumentParser
from concurrent.futures import ThreadPoolExecutor, as_completed
from .lib.saj import StreamAnalyticsJobs
from .lib.utils import chkpath, mklog


def get_args():
    parser = ArgumentParser(description="Start or stop Stream Analytics Jobs")
    parser.add_argument(
        "-C",
        "--config",
        type=chkpath,
        metavar=("PATH"),
        default=f"{os.path.expanduser('~')}/.azure.ini",
        help="path to azure configuration file",
    )
    parser.add_argument(
        "-r", "--resource_group", metavar=("NAME"), help="azure resource group"
    )
    parser.add_argument(
        "-j",
        "--stream_analytics_jobs",
        metavar=("JOBS"),
        nargs="+",
        help="list of azure stream analytics jobs",
    )
    parser.add_argument(
        "-a",
        "--action",
        metavar=("START/STOP"),
        help="action to carry out - start or stop.",
    )
    parser.add_argument("-v", action="count", default=0, help="increase verbosity")
    return parser.parse_args()


def sajctl(config, rg, jobs, action):
    saj = StreamAnalyticsJobs(config, rg)
    print(f"Sending {action} to " + ", ".join(jobs) + "...")

    # http://masnun.com/2016/03/29/python-a-quick-introduction-to-the-concurrent-futures-module.html
    with ThreadPoolExecutor(max_workers=len(jobs)) as executor:
        future_job = {
            executor.submit(saj.toggle_stream_analytics_job, job, action): job
            for job in jobs
        }
        for future in as_completed(future_job):
            job = future_job[future]
            print(f"Status of {job}: ", end="", flush="True")
            try:
                result = future.result()
            except ValueError as error:
                print(f"FAILED")
                logging.error(error)
            else:
                print(result["properties"]["jobState"].upper())


def main():
    args = get_args()
    mklog(args.v)
    sajctl(args.config, args.resource_group, args.stream_analytics_jobs, args.action)


if __name__ == "__main__":
    main()



# Copyright (c) 2018, Toby Slight. All rights reserved.
# ISC License (ISCL) - see LICENSE file for details.

name = "azure_extras"
from .lib.az import AzureExtras
from .lib.app import AppService
from .lib.kudu import KuduClient
from .lib.saj import StreamAnalyticsJobs
